@@ -255,7 +255,7 @@ class ReconstructESDCoincidences(object):
         """
         length = self.coincidences.nrows
         coincidences = self.cq.all_coincidences()
-        coincidence_events = pbar(self.cq.all_events(coincidences),
+        coincidence_events = pbar(self.cq.all_events(coincidences, n=0),
                                   length=length, show=self.progress)
         angles = [self._reconstruct_direction(c) for c in coincidence_events]
         self.theta, self.phi, self.station_numbers = zip(*angles)
@@ -312,7 +312,7 @@ class ReconstructESDCoincidences(object):
         self.offsets = {102: [-3.1832, 0.0000, 0.0000, 0.0000],
                         104: [-1.5925, -5.0107, 0.0000, 0.0000],
                         105: [-14.1325, -10.9451, 0.0000, 0.0000],
-                        501: [-1.10338,  0.0000, 5.35711, 3.1686],
+                        501: [-1.10338, 0.0000, 5.35711, 3.1686],
                         502: [-8.11711, -8.5528, -8.72451, -9.3388],
                         503: [-22.9796, -26.6098, -22.7522, -21.8723],
                         504: [-15.4349, -15.2281, -15.1860, -16.5545],
@@ -352,7 +352,7 @@ class ReconstructESDCoincidences(object):
 
         # Currently disabled station offsets because they do not work well.
 
-        # Now determine the station offsets and those to detector offsets
+        # Now determine station offsets and add those to detector offsets
         ref_station = self.cluster.get_station(ref_station_number)
         ref_id = ref_station.station_id
         ref_z = ref_station.calc_center_of_mass_coordinates()[2]
