@@ -75,18 +75,8 @@ class GroundParticlesSimulation(HiSPARCSimulation):
                               'energy': event_header.energy,
                               'particle': event_header.particle}
 
-        # DF: This is the fastest implementation I could come up with.  I
-        # timed several permutations of numpy / math, and tried a Monte
-        # Carlo method in which I pick x and y in a square (fast) and then
-        # determine if they fall inside a circle or not (surprisingly
-        # slow, because of an if-statement, and despite some optimizations
-        # suggested by HM).
-
         for i in pbar(range(self.N)):
-            r = sqrt(np.random.uniform(0, R ** 2))
-            phi = np.random.uniform(-pi, pi)
-            x = r * cos(phi)
-            y = r * sin(phi)
+            x, y = self.generate_core_position(R)
 
             # Subtract Corsika shower azimuth from desired shower azimuth
             # make it fit in (-pi, pi] to get rotation angle of the cluster.
@@ -168,12 +158,14 @@ class GroundParticlesSimulation(HiSPARCSimulation):
 
             ext_timestamp = shower_parameters['ext_timestamp']
             ext_timestamp += int(trigger_time + station.gps_offset +
-                                self.simulate_gps_uncertainty())
+                                 self.simulate_gps_uncertainty())
             timestamp = int(ext_timestamp / int(1e9))
             nanoseconds = int(ext_timestamp % int(1e9))
 
             gps_timestamp = {'ext_timestamp': ext_timestamp,
-                             'timestamp': timestamp, 'nanoseconds': nanoseconds}
+                             'timestamp': timestamp,
+                             'nanoseconds': nanoseconds,
+                             't_trigger': trigger_time}
             station_observables.update(gps_timestamp)
 
         return station_observables
